@@ -44,19 +44,27 @@
 #'   random strand of each chromosome.) The default action is to skip
 #'   recombination in founders who are uninformative for IBD sharing in the
 #'   `ids` individuals.
-#'
+#' @param simplify1 A logical, by default TRUE, removing the outer list layer
+#'   when N = 1. See Value.
 #' @param seed An integer to be passed on to [set.seed()]).
 #' @param verbose A logical.
 #'
 #' @return A list of `N` objects of class `genomeSim`.
 #'
+#'   If N = 1 the outer list layer is removed by default, which is typically
+#'   desired in interactive use (especially when piping). To enforce a list
+#'   output, add `simplify1 = FALSE`.
+#'
 #'   A `genomeSim` object is essentially a numerical matrix describing the
 #'   allele flow through the pedigree in a single simulated. Each row
-#'   corresponds to a chromosomal segment. The first 4 columns describe the
-#'   segment (chromosome, start, end, length), and are followed by two columns
-#'   (paternal allele, maternal allele) for each of the `ids` individuals.
+#'   corresponds to a chromosomal segment. The first 3 columns (chrom, startMB,
+#'   endMB) describe the physical location of the segment. Next, the genetic
+#'   coordinates (startCM, endCM), which are computed from `map` by averaging
+#'   the male and female values. Then follow the allele columns, two for each
+#'   individual in `ids`, suffixed by ":p" and ":m" signifying the paternal and
+#'   maternal alleles, respectively.
 #'
-#'   If `ids` has length 1, a column named "Aut" is added, whose entries are 1
+#'   If `ids` has length 1, a column named `Aut` is added, whose entries are 1
 #'   for autozygous segments and 0 otherwise.
 #'
 #'   If `ids` has length 2, two columns are added:
@@ -70,7 +78,7 @@
 #'   * `Sigma` : The condensed identity ("Jacquard") state of each segment,
 #'   given as an integer in the range 1-9. The numbers correspond to the
 #'   standard ordering of the condensed states. In particular, for non-inbred
-#'   individuals the states 9, 8, 7 correspond to IBD status 0, 1, 2
+#'   individuals, the states 9, 8, 7 correspond to IBD status 0, 1, 2
 #'   respectively.
 #'
 #' @references Halldorsson et al. _Characterizing mutagenic effects of
@@ -78,25 +86,29 @@
 #'   (2019).
 #'
 #' @examples
-#'
-#' hs = halfSibPed()
-#' sims = ibdsim(hs, N = 2, map = uniformMap(M = 1), seed = 10)
-#' sims
 #' 
-#' # Inspect the first simulation
-#' sims[[1]]
-#' haploDraw(hs, sims[[1]], pos = 2)
+#' ### Example 1: Half siblings ###
+#' 
+#' hs = halfSibPed()
+#' sim = ibdsim(hs, map = uniformMap(M = 1), seed = 10)
+#' sim
 #'
-#' # Full sib mating: all 9 states are possible
+#' # Plot haplotypes
+#' haploDraw(hs, sim)
+#'
+#' #' ### Example 2: Full sib mating ###
+#' 
 #' x = fullSibMating(1)
-#' sim = ibdsim(x, N = 1, ids = 5:6, map = uniformMap(M = 10), seed = 1)
-#' s = sim[[1]]
-#' stopifnot(setequal(s[, 'Sigma'], 1:9))
+#' sim = ibdsim(x, ids = 5:6, map = uniformMap(M = 10), seed = 1)
+#' head(sim)
+#' 
+#' # All 9 identity states are present
+#' stopifnot(setequal(sim[, 'Sigma'], 1:9))
 #'
 #' @export
 ibdsim = function(x, N = 1, ids = labels(x), map = "decode",
                   model = c("chi", "haldane"), skipRecomb = NULL, 
-                  seed = NULL, verbose = TRUE) {
+                  simplify1 = TRUE, seed = NULL, verbose = TRUE) {
   # Check input
   if(!is.ped(x))
     stop2("The first argument must be a `ped` object")
@@ -175,6 +187,11 @@ ibdsim = function(x, N = 1, ids = labels(x), map = "decode",
   if(verbose)
     message("Total time used: ", format(Sys.time() - starttime, digits = 3))
   
+  # Return single sim if N = 1
+  if(simplify1 && N == 1)
+    return(genomeSimList[[1]])
+  
+  # Otherwise the full list
   structure(genomeSimList, 
             pedigree = x, 
             ids = ids, 
